@@ -91,7 +91,7 @@ struct _pthread_descr_struct __pthread_initial_thread = {
   0,                          /* Always index 0 */
   0,                          /* int p_report_events */
   {{{0, }}, 0, NULL},         /* td_eventbuf_t p_eventbuf */
-  ATOMIC_INITIALIZER,         /* struct pthread_atomic p_resume_count */
+  __ATOMIC_INITIALIZER,       /* struct pthread_atomic p_resume_count */
   0,                          /* char p_woken_by_cancel */
   0,                          /* char p_condvar_avail */
   0,                          /* char p_sem_avail */
@@ -148,7 +148,7 @@ struct _pthread_descr_struct __pthread_manager_thread = {
   1,                          /* Always index 1 */
   0,                          /* int p_report_events */
   {{{0, }}, 0, NULL},         /* td_eventbuf_t p_eventbuf */
-  ATOMIC_INITIALIZER,         /* struct pthread_atomic p_resume_count */
+  __ATOMIC_INITIALIZER,       /* struct pthread_atomic p_resume_count */
   0,                          /* char p_woken_by_cancel */
   0,                          /* char p_condvar_avail */
   0,                          /* char p_sem_avail */
@@ -352,7 +352,7 @@ is_smp_system (void)
 		sizeof (sysctl_args) / sizeof (sysctl_args[0]),
 		buf, &reslen, NULL, 0) < 0)
     {
-      /*This was not successful.  Now try reading the /proc filesystem.  */
+      /* This was not successful.  Now try reading the /proc filesystem.  */
       int fd = __open ("/proc/sys/kernel/version", O_RDONLY);
       if (__builtin_expect (fd, 0) == -1
 	  || (reslen = __read (fd, buf, sizeof (buf))) <= 0)
@@ -375,7 +375,9 @@ is_smp_system (void)
 
 static void pthread_initialize(void) __attribute__((constructor));
 
+#ifndef HAVE_Z_NODELETE
 extern void *__dso_handle __attribute__ ((weak));
+#endif
 
 
 /* Do some minimal initialization which has to be done during the
